==> ZenTaoPMS-ipd1.2-php8.1.zip: zentaopms/module/chart/lang/zh-cn.php <==
<?php
$lang->chart->preview  = '查看图表';
$lang->chart->query    = '查询';
$lang->chart->toDesign = '进入设计';

$lang->chart->group       = '所属分组';
$lang->chart->field       = '关联字段';
$lang->chart->agg         = '汇总';
$lang->chart->chooseField = '选择字段';
$lang->chart->aggType     = '统计方式';
$lang->chart->other       = '其他';
$lang->chart->unlimited   = '不限';
$lang->chart->colon       = '至';

$lang->chart->fieldTypeList = array();
$lang->chart->fieldTypeList['input']     = '文本框';
$lang->chart->fieldTypeList['date']      = '日期';
$lang->chart->fieldTypeList['datetime']  = '时间';
$lang->chart->fieldTypeList['select']    = '下拉菜单';
//$lang->chart->fieldTypeList['condition'] = '条件筛选';

$lang->chart->groupWeek = '%s年第%s周';

$lang->chart->noChart         = '暂时没有图表';
$lang->chart->noChartSelected = '请选择至少一个图表。';
$lang->chart->chartMaxChecked = '最多只能选择%s个图表。';

$lang->chart->aggList = array();
$lang->chart->aggList['count']    = '计数';
$lang->chart->aggList['distinct'] = '去重后计数';
$lang->chart->aggList['avg']      = '平均值';
$lang->chart->aggList['sum']      = '求和';
$lang->chart->aggList['max']      = '最大值';
$lang->chart->aggList['min']      = '最小值';

$lang->chart->typeList = array();
$lang->chart->typeList['pie']         = '饼图';
$lang->chart->typeList['line']        = '折线图';
$lang->chart->typeList['waterpolo']   = '水球图';
$lang->chart->typeList['radar']       = '雷达图';
$lang->chart->typeList['cluBarY']     = '簇状条形图';
$lang->chart->typeList['stackedBarY'] = '堆积条形图';
$lang->chart->typeList['cluBarX']     = '簇状柱形图';
$lang->chart->typeList['stackedBar']  = '堆积柱形图';

$lang->chart->conditionList['eq'] = '=';

==> ZenTaoPMS-ipd2.6.1-php8.1.zip: zentaopms/module/chart/lang/zh-cn.php <==
<?php
$lang->chart->preview  = '查看图表';
$lang->chart->query    = '查询';
$lang->chart->toDesign = '进入设计';

$lang->chart->accessDenied  = '您无权访问该图表';
$lang->chart->acl = '访问控制';
$lang->chart->aclList['open']    = '公开（有图表视图权限与所在维度的访问权限即可访问）';
$lang->chart->aclList['private'] = '私有（仅创建者和白名单用户可访问）';

$lang->chart->group       = '所属分组';
$lang->chart->field       = '关联字段';
$lang->chart->agg         = '汇总';
$lang->chart->chooseField = '选择字段';
$lang->chart->aggType     = '统计方式';
$lang->chart->other       = '其他';
$lang->chart->unlimited   = '不限';
$lang->chart->colon       = '至';

$lang->chart->fieldTypeList = array();
$lang->chart->fieldTypeList['input']     = '文本框';
$lang->chart->fieldTypeList['date']      = '日期';
$lang->chart->fieldTypeList['datetime']  = '时间';
$lang->chart->fieldTypeList['select']    = '下拉菜单';
//$lang->chart->fieldTypeList['condition'] = '条件筛选';

$lang->chart->groupWeek = '%s年第%s周';

$lang->chart->noChart         = '暂时没有图表';
$lang->chart->noData          = '暂时没有数据';
$lang->chart->noChartSelected = '请选择至少一个图表。';
$lang->chart->chartMaxChecked = '最多只能选择%s个图表。';

$lang->chart->featureBar = array();
$lang->chart->featureBar['preview'] = array();

$lang->chart->aggList = array();
$lang->chart->aggList['count']    = '计数';
$lang->chart->aggList['distinct'] = '去重后计数';
$lang->chart->aggList['avg']      = '平均值';
$lang->chart->aggList['sum']      = '求和';
$lang->chart->aggList['max']      = '最大值';
$lang->chart->aggList['min']      = '最小值';

$lang->chart->typeList = array();
$lang->chart->typeList['pie']         = '饼图';
$lang->chart->typeList['line']        = '折线图';
$lang->chart->typeList['waterpolo']   = '水球图';
$lang->chart->typeList['radar']       = '雷达图';
$lang->chart->typeList['cluBarY']     = '簇状条形图';
$lang->chart->typeList['stackedBarY'] = '堆积条形图';
$lang->chart->typeList['cluBarX']     = '簇状柱形图';
$lang->chart->typeList['stackedBar']  = '堆积柱形图';

$lang->chart->conditionList['eq'] = '=';
